package com.dcsoft.system.kq.mapper;


import com.dcsoft.system.kq.domain.KqGroupUser;

import java.util.List;

/**
 * 考勤组人员Mapper接口
 *
 * @author dcsoft
 * @date 2023-01-11
 */
public interface KqGroupUserMapper
{
    /**
     * 查询考勤组人员
     *
     * @param groupId 考勤组人员主键
     * @return 考勤组人员
     */
    public KqGroupUser selectKqGroupUserByGroupId(Long groupId);

    /**
     * 查询考勤组人员列表
     *
     * @param kqGroupUser 考勤组人员
     * @return 考勤组人员集合
     */
    public List<KqGroupUser> selectKqGroupUserList(KqGroupUser kqGroupUser);

    /**
     * 新增考勤组人员
     *
     * @param kqGroupUser 考勤组人员
     * @return 结果
     */
    public int insertKqGroupUser(KqGroupUser kqGroupUser);

    /**
     * 修改考勤组人员
     *
     * @param kqGroupUser 考勤组人员
     * @return 结果
     */
    public int updateKqGroupUser(KqGroupUser kqGroupUser);

    /**
     * 删除考勤组人员
     *
     * @param groupId 考勤组人员主键
     * @return 结果
     */
    public int deleteKqGroupUserByGroupId(Long groupId);

    /**
     * 批量删除考勤组人员
     *
     * @param groupIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteKqGroupUserByGroupIds(Long[] groupIds);


    public int batchGroupUser(List<KqGroupUser> kqGroupUserList);

    /**
     * 删除考勤组人员
     *
     * @param groupId 考勤组人员主键
     * @return 结果
     */
    public int deleteKqGroupUserByUserId(Long userId);

}
